cheesecake.model

Package cheesecake :: Module model |
[hide private]
[frames] | no frames]

## Module model
source code

Code borrowed from Michael Hudson's docextractor package with the author's permission.

The original code is available at http://codespeak.net/svn/user/mwh/docextractor/.

Changes:
  - do not print warnings to stdout (in System.warning)
  - collect all function calls

Classes | [hide private]
Documentable |
Package |
Module |
Class |
Function |
ModuleVistor |
System |
ImportStarFinder |

Functions | [hide private]
| get_call_name(node)
| get_function_calls(node, fc)
| expandModname(system, modname, givewarning=True)
| processModuleAst(ast, name, system)
| fromText(src, modname='<test>', system=None)
| preprocessDirectory(system, dirpath)
| findImportStars(system)
| extractDocstrings(system)
| finalStateComputations(system)
| processDirectory(system, dirpath)
| toposort(input, edges)
| main(systemcls, argv)

Variables | [hide private]
states |

Function Details | [hide private]

### get_call_name(node) | source code

### get_function_calls(node, fc) | source code

### expandModname(system, modname, givewarning=True) | source code

### processModuleAst(ast, name, system) | source code

### fromText(src, modname='<test>', system=None) | source code

### preprocessDirectory(system, dirpath) | source code

### findImportStars(system) | source code

### extractDocstrings(system) | source code

### finalStateComputations(system) | source code

### processDirectory(system, dirpath) | source code

### toposort(input, edges) | source code

### main(systemcls, argv) | source code

Variables Details | [hide private]

    ### states Value:
        ['blank', 'preparse', 'importstarred', 'parsed', 'finalized']